[][src]Crate cargo_clone

A library to create a local clone of a Cargo package.

This fetches the repository for a package as defined in the repository field of a Cargo package. If there is no repository, it can also fetch the .crate file from crates.io.

Structs

Cloner

A struct containg all url and workspace information necessary to clone a crate.

Enums

CloneMethodKind

An enum representation of supported cloning methods.

Constants

DEFAULT_BITBUCKET_URL

https://api.bitbucket.org/2.0/repositories

DEFAULT_GITHUB_URL

https://github.com

DEFAULT_GITLAB_URL

https://gitlab.com

DEFAULT_REGISTRY_URL

https://crates.io

Functions

clone

A helper function for cloning a crate into the current working directory.