CloneMethodKind

Enum CloneMethodKind 

pub enum CloneMethodKind {
    Crate,
    Git,
    Mercurial,
    Pijul,
    Fossil,
    Auto,
}
An enum representation of supported cloning methods.

Variants



Crate

Downloads the .crate file from the registry and extracts it.



Git

Clones using git.



Mercurial

Clones using hg.



Pijul

Clones using pijul.



Fossil

Clones using fossil.



Auto

Attempts to automatically detect which method to use using heuristics.

Implementations

Source

impl CloneMethodKind

pub fn command(&self) -> &str

Returns the underlying command line command for the method.

pub fn from(method_name: &str) -> Option<CloneMethodKind>

Creates a CloneMethodKind from a method name. If no name matches then None is returned. Current options are crate, git, hg, mercurial, pijul, fossil, and auto