[−][src]Enum cargo_clone::CloneMethodKind
An enum representation of supported cloning methods.
Variants
Downloads the .crate file from the registry and extracts it.
Clones using git.
Clones using hg.
Clones using pijul.
Clones using fossil.
Attempts to automatically detect which method to use using heuristics.
Implementations
impl CloneMethodKind[src]
pub fn command(&self) -> &str[src]
Returns the underlying command line command for the method.
pub fn from(method_name: &str) -> Option<CloneMethodKind>[src]
Creates a CloneMethodKind from a method name. If no name matches then None is returned.
Current options are crate, git, hg, mercurial, pijul, fossil, and auto