[−][src]Struct cargo_clone::Cloner
A struct containg all url and workspace information necessary to clone a crate.
Implementations
impl Cloner[src]
pub fn new() -> Cloner[src]
Create a Crate Cloner using all the default settings
pub fn set_registry_url(&mut self, value: impl Into<String>) -> &mut Self[src]
Sets the URL to use for downloading .crate files from crates.io.
pub fn set_github_url(&mut self, value: impl Into<String>) -> &mut Self[src]
Sets the URL to use for downloading GitHub repositories.
pub fn set_gitlab_url(&mut self, value: impl Into<String>) -> &mut Self[src]
Sets the URL to use for downloading GitLab repositories.
pub fn set_bitbucket_url(&mut self, value: impl Into<String>) -> &mut Self[src]
Sets the URL to use for downloading Bitbucket repositories.
pub fn set_out_dir(&mut self, value: impl Into<PathBuf>) -> &mut Self[src]
Sets the directory where the clone will be done.
The package will appear as a directory underneath the given path.
pub fn clone(
&self,
method_kind: CloneMethodKind,
spec: &str,
version: Option<&str>,
extra: &[&str]
) -> Result<(), Error>[src]
&self,
method_kind: CloneMethodKind,
spec: &str,
version: Option<&str>,
extra: &[&str]
) -> Result<(), Error>
Clones a crate using the provided method.
method_kind- Method to fetch crate.spec- The name of the crate to cloneversion- The semantic version (semver) of the spec crate to cloneextra- Additional arguments passed to clone command.